@@ -1,7 +1,7 @@
 /* Copyright 2003-2004 Roger Dingledine
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson */
 /* See LICENSE for licensing information */
-/* $Id: util.h,v 1.155 2006/03/05 09:50:25 nickm Exp $ */
+/* $Id: util.h,v 1.158 2006/03/15 23:35:55 arma Exp $ */
 
 /**
  * \file util.h
@@ -10,7 +10,7 @@
 
 #ifndef __UTIL_H
 #define __UTIL_H
-#define UTIL_H_ID "$Id: util.h,v 1.155 2006/03/05 09:50:25 nickm Exp $"
+#define UTIL_H_ID "$Id: util.h,v 1.158 2006/03/15 23:35:55 arma Exp $"
 
 #include "orconfig.h"
 #include "torint.h"
@@ -41,9 +41,9 @@
 #define tor_assert(expr) do {                                           \
     if (!(expr)) {                                                      \
       log(LOG_ERR, LD_BUG, "%s:%d: %s: Assertion %s failed; aborting.", \
-          _SHORT_FILE_, __LINE__, __FUNCTION__, #expr);                 \
+          _SHORT_FILE_, __LINE__, __func__, #expr);                 \
       fprintf(stderr,"%s:%d %s: Assertion %s failed; aborting.\n",      \
-              _SHORT_FILE_, __LINE__, __FUNCTION__, #expr);             \
+              _SHORT_FILE_, __LINE__, __func__, #expr);             \
       abort();                                                          \
     } } while (0)
 #endif
