@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: circuitbuild.c,v 1.229 2006/03/27 02:25:33 arma Exp $ */
+/* $Id: circuitbuild.c,v 1.230 2006/04/02 22:59:59 nickm Exp $ */
 const char circuitbuild_c_id[] =
-  "$Id: circuitbuild.c,v 1.229 2006/03/27 02:25:33 arma Exp $";
+  "$Id: circuitbuild.c,v 1.230 2006/04/02 22:59:59 nickm Exp $";
 
 /**
  * \file circuitbuild.c
@@ -1284,7 +1284,8 @@ choose_good_exit_server_general(routerlist_t *dir, int need_uptime,
   }
   if (options->StrictExitNodes) {
     log_warn(LD_CIRC,
-             "No exit routers seem to be running; can't choose an exit.");
+             "No specified exit routers seem to be running, and "
+             "StrictExitNodes is set: can't choose an exit.");
   }
   return NULL;
 }
