@@ -2,9 +2,9 @@
  * Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: circuituse.c,v 1.123 2006/03/27 02:25:34 arma Exp $ */
+/* $Id: circuituse.c,v 1.124 2006/04/09 21:36:37 arma Exp $ */
 const char circuituse_c_id[] =
-  "$Id: circuituse.c,v 1.123 2006/03/27 02:25:34 arma Exp $";
+  "$Id: circuituse.c,v 1.124 2006/04/09 21:36:37 arma Exp $";
 
 /**
  * \file circuituse.c
@@ -1136,6 +1136,7 @@ connection_ap_handshake_attach_circuit(connection_t *conn)
 {
   int retval;
   int conn_age;
+  int severity;
 
   tor_assert(conn);
   tor_assert(conn->type == CONN_TYPE_AP);
@@ -1143,11 +1144,12 @@ connection_ap_handshake_attach_circuit(connection_t *conn)
   tor_assert(conn->socks_request);
 
   conn_age = time(NULL) - conn->timestamp_created;
+  severity = (!conn->addr && !conn->port) ? LOG_INFO : LOG_NOTICE;
   if (conn_age > get_options()->SocksTimeout) {
-    log_notice(LD_APP,
-               "Tried for %d seconds to get a connection to %s:%d. Giving up.",
-               conn_age, safe_str(conn->socks_request->address),
-               conn->socks_request->port);
+    log_fn(severity, LD_APP,
+           "Tried for %d seconds to get a connection to %s:%d. Giving up.",
+           conn_age, safe_str(conn->socks_request->address),
+           conn->socks_request->port);
     return -1;
   }
 
