@@ -1,8 +1,8 @@
 /* Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: control.c,v 1.183 2006/03/27 06:49:25 nickm Exp $ */
+/* $Id: control.c,v 1.189 2006/04/02 22:19:01 arma Exp $ */
 const char control_c_id[] =
-  "$Id: control.c,v 1.183 2006/03/27 06:49:25 nickm Exp $";
+  "$Id: control.c,v 1.189 2006/04/02 22:19:01 arma Exp $";
 
 /**
  * \file control.c
@@ -1166,7 +1166,6 @@ handle_control_mapaddress(connection_t *conn, uint32_t len, const char *body)
   else
     smartlist_split_string(lines, body, " ",
                            SPLIT_SKIP_SPACE|SPLIT_IGNORE_BLANK, 0);
-  /* XXXX Make errors conformant. */
   SMARTLIST_FOREACH(lines, char *, line,
   {
     tor_strlower(line);
@@ -1177,11 +1176,25 @@ handle_control_mapaddress(connection_t *conn, uint32_t len, const char *body)
     if (smartlist_len(elts) == 2) {
       const char *from = smartlist_get(elts,0);
       const char *to = smartlist_get(elts,1);
+      size_t anslen = strlen(line)+512;
+      char *ans = tor_malloc(anslen);
       if (!is_plausible_address(from)) {
+        if (!v0) {
+          tor_snprintf(ans, anslen,
+            "512-syntax error: invalid address '%s'", from);
+          smartlist_add(reply, ans);
+        } else
+          tor_free(ans); /* don't respond if v0 */
         log_warn(LD_CONTROL,
                  "Skipping invalid argument '%s' in MapAddress msg",
              from);
       } else if (!is_plausible_address(to)) {
+        if (!v0) {
+          tor_snprintf(ans, anslen,
+            "512-syntax error: invalid address '%s'", to);
+          smartlist_add(reply, ans);
+        } else
+          tor_free(ans); /* don't respond if v0 */
         log_warn(LD_CONTROL,
                  "Skipping invalid argument '%s' in MapAddress msg", to);
       } else if (!strcmp(from, ".") || !strcmp(from, "0.0.0.0")) {
@@ -1189,12 +1202,16 @@ handle_control_mapaddress(connection_t *conn, uint32_t len, const char *body)
               !strcmp(from,".") ? RESOLVED_TYPE_HOSTNAME : RESOLVED_TYPE_IPV4,
                tor_strdup(to));
         if (!address) {
+          if (!v0) {
+            tor_snprintf(ans, anslen,
+              "451-resource exhausted: skipping '%s'", line);
+            smartlist_add(reply, ans);
+          } else
+            tor_free(ans); /* don't respond if v0 */
           log_warn(LD_CONTROL,
                    "Unable to allocate address for '%s' in MapAddress msg",
                    safe_str(line));
         } else {
-          size_t anslen = strlen(address)+strlen(to)+8;
-          char *ans = tor_malloc(anslen);
           if (v0)
             tor_snprintf(ans, anslen, "%s %s", address, to);
           else
@@ -1204,17 +1221,21 @@ handle_control_mapaddress(connection_t *conn, uint32_t len, const char *body)
       } else {
         addressmap_register(from, tor_strdup(to), 1);
         if (v0)
-          smartlist_add(reply, tor_strdup(line));
-        else {
-          size_t anslen = strlen(line)+8;
-          char *ans = tor_malloc(anslen);
+          tor_snprintf(ans, anslen, "%s", line);
+        else
           tor_snprintf(ans, anslen, "250-%s", line);
-          smartlist_add(reply, ans);
-        }
+        smartlist_add(reply, ans);
       }
     } else {
-      log_warn(LD_CONTROL,
-               "Skipping MapAddress line with wrong number of items.");
+      if (!v0) {
+        size_t anslen = strlen(line)+256;
+        char *ans = tor_malloc(anslen);
+        tor_snprintf(ans, anslen, "512-syntax error: mapping '%s' is "
+                     "not of expected form 'foo=bar'.", line);
+        smartlist_add(reply, ans);
+      }
+      log_info(LD_CONTROL, "Skipping MapAddress '%s': wrong "
+                           "number of items.", safe_str(line));
     }
     SMARTLIST_FOREACH(elts, char *, cp, tor_free(cp));
     smartlist_clear(elts);
@@ -1226,16 +1247,22 @@ handle_control_mapaddress(connection_t *conn, uint32_t len, const char *body)
   if (v0) {
     r = smartlist_join_strings(reply, "\n", 1, &sz);
     send_control_done2(conn,r,sz);
+    tor_free(r);
   } else {
-    if (smartlist_len(reply))
+    if (smartlist_len(reply)) {
       ((char*)smartlist_get(reply,smartlist_len(reply)-1))[3] = ' ';
-    r = smartlist_join_strings(reply, "\r\n", 1, &sz);
-    connection_write_to_buf(r, sz, conn);
+      r = smartlist_join_strings(reply, "\r\n", 1, &sz);
+      connection_write_to_buf(r, sz, conn);
+      tor_free(r);
+    } else {
+      const char *response =
+        "512 syntax error: not enough arguments to mapaddress.\r\n";
+      connection_write_to_buf(response, strlen(response), conn);
+    }
   }
 
   SMARTLIST_FOREACH(reply, char *, cp, tor_free(cp));
   smartlist_free(reply);
-  tor_free(r);
   return 0;
 }
 
@@ -1485,14 +1512,13 @@ handle_getinfo_helper(const char *question, char **answer)
     smartlist_t *status_list;
     size_t len;
     char *cp;
-    if (!get_options()->DirPort)
-      return 0;
-    status_list = smartlist_create();
-    if (!dirserv_get_networkstatus_v2(status_list,
-                                      question+strlen("dir/status/"))) {
-      smartlist_free(status_list);
+    if (!get_options()->DirPort) {
+      log_warn(LD_CONTROL, "getinfo dir/status/ requires an open dirport.");
       return 0;
     }
+    status_list = smartlist_create();
+    dirserv_get_networkstatus_v2(status_list,
+                                 question+strlen("dir/status/"));
     len = 0;
     SMARTLIST_FOREACH(status_list, cached_dir_t *, d, len += d->dir_len);
     cp = *answer = tor_malloc(len+1);
