@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: directory.c,v 1.366 2006/03/27 07:33:13 weasel Exp $ */
+/* $Id: directory.c,v 1.370 2006/04/10 01:35:56 nickm Exp $ */
 const char directory_c_id[] =
-  "$Id: directory.c,v 1.366 2006/03/27 07:33:13 weasel Exp $";
+  "$Id: directory.c,v 1.370 2006/04/10 01:35:56 nickm Exp $";
 
 #include "or.h"
 
@@ -89,7 +89,7 @@ directory_post_to_dirservers(uint8_t purpose, const char *payload,
   int post_via_tor;
   int post_to_v1_only;
 
-  router_get_trusted_dir_servers(&dirservers);
+  dirservers = router_get_trusted_dir_servers();
   tor_assert(dirservers);
   /* Only old dirservers handle rendezvous descriptor publishing. */
   post_to_v1_only = (purpose == DIR_PURPOSE_UPLOAD_RENDDESC);
@@ -123,7 +123,8 @@ directory_get_from_dirserver(uint8_t purpose, const char *resource,
   int directconn = !purpose_is_private(purpose);
 
   int need_v1_support = purpose == DIR_PURPOSE_FETCH_DIR ||
-                        purpose == DIR_PURPOSE_FETCH_RUNNING_LIST;
+                        purpose == DIR_PURPOSE_FETCH_RUNNING_LIST ||
+                        purpose == DIR_PURPOSE_FETCH_RENDDESC;
   int need_v2_support = purpose == DIR_PURPOSE_FETCH_NETWORKSTATUS ||
                         purpose == DIR_PURPOSE_FETCH_SERVERDESC;
 
@@ -154,7 +155,7 @@ directory_get_from_dirserver(uint8_t purpose, const char *resource,
         log_info(LD_DIR,
                  "No router found for %s; falling back to dirserver list",
                  which);
-        rs = router_pick_trusteddirserver(1, 1, 1,
+        rs = router_pick_trusteddirserver(need_v1_support, 1, 1,
                                           retry_if_no_servers);
         if (!rs)
           directconn = 0; /* last resort: try routing it via Tor */
@@ -165,7 +166,7 @@ directory_get_from_dirserver(uint8_t purpose, const char *resource,
     /* Never use fascistfirewall; we're going via Tor. */
     if (purpose == DIR_PURPOSE_FETCH_RENDDESC) {
       /* only ask authdirservers, any of them will do */
-      rs = router_pick_trusteddirserver(0, 0, 0, retry_if_no_servers);
+      rs = router_pick_trusteddirserver(1, 0, 0, retry_if_no_servers);
     } else {
       /* anybody with a non-zero dirport will do. Disregard firewalls. */
       rs = router_pick_directory_server(1, 0, need_v2_support,
@@ -295,6 +296,9 @@ connection_dir_download_networkstatus_failed(connection_t *conn)
   }
   if (!strcmpstart(conn->requested_resource, "all")) {
     /* We're a non-authoritative directory cache; try again. */
+    smartlist_t *trusted_dirs = router_get_trusted_dir_servers();
+    SMARTLIST_FOREACH(trusted_dirs, trusted_dir_server_t *, ds,
+                      ++ds->n_networkstatus_failures);
     directory_get_from_dirserver(conn->purpose, "all.z",
                                  0 /* don't retry_if_no_servers */);
   } else if (!strcmpstart(conn->requested_resource, "fp/")) {
@@ -992,6 +996,16 @@ connection_dir_client_reached_eof(connection_t *conn)
       which = smartlist_create();
       dir_split_resource_into_fingerprints(conn->requested_resource+3,
                                            which, NULL, 0);
+    } else if (conn->requested_resource &&
+               !strcmpstart(conn->requested_resource, "all")) {
+      which = smartlist_create();
+      SMARTLIST_FOREACH(router_get_trusted_dir_servers(),
+                        trusted_dir_server_t *, ds,
+        {
+          char *cp = tor_malloc(HEX_DIGEST_LEN+1);
+          base16_encode(cp, HEX_DIGEST_LEN+1, ds->digest, DIGEST_LEN);
+          smartlist_add(which, cp);
+        });
     }
     cp = body;
     while (*cp) {
@@ -1430,10 +1444,7 @@ directory_handle_command_get(connection_t *conn, char *headers,
     const char *key = url + strlen("/tor/status/");
     if (deflated)
       url[url_len-2] = '\0';
-    if (dirserv_get_networkstatus_v2(dir_objs, key)) {
-      smartlist_free(dir_objs);
-      return 0;
-    }
+    dirserv_get_networkstatus_v2(dir_objs, key);
     if (!strcmpstart(key, "fp/"))
       request_type = deflated?"/tor/status/fp.z":"/tor/status/fp";
     else if (!strcmpstart(key, "authority"))
@@ -1826,7 +1837,7 @@ dir_networkstatus_download_failed(smartlist_t *failed)
 }
 
 /** Called when one or more routerdesc fetches have failed (with uppercase
- * fingerprints listed in <b>failed</>). */
+ * fingerprints listed in <b>failed</b>). */
 static void
 dir_routerdesc_download_failed(smartlist_t *failed)
 {
