@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: dirserv.c,v 1.316 2006/03/27 02:25:34 arma Exp $ */
+/* $Id: dirserv.c,v 1.328 2006/04/10 01:35:56 nickm Exp $ */
 const char dirserv_c_id[] =
-  "$Id: dirserv.c,v 1.316 2006/03/27 02:25:34 arma Exp $";
+  "$Id: dirserv.c,v 1.328 2006/04/10 01:35:56 nickm Exp $";
 
 #include "or.h"
 
@@ -592,13 +592,12 @@ dirserver_getinfo_unregistered(const char *question)
   answerlist = smartlist_create();
   SMARTLIST_FOREACH(rl->routers, routerinfo_t *, ent, {
     r = dirserv_router_get_status(ent, NULL);
-    if (ent->bandwidthcapacity >= (size_t)min_bw &&
-        ent->bandwidthrate >= (size_t)min_bw &&
+    if (router_get_advertised_bandwidth(ent) >= (size_t)min_bw &&
         r != FP_NAMED) {
       /* then log this one */
       tor_snprintf(buf, sizeof(buf),
                    "%s: BW %d on '%s'.",
-                   ent->nickname, ent->bandwidthcapacity,
+                   ent->nickname, router_get_advertised_bandwidth(ent),
                    ent->platform ? ent->platform : "");
       smartlist_add(answerlist, tor_strdup(buf));
     }
@@ -737,14 +736,28 @@ format_versions_list(config_line_t *ln)
     smartlist_split_string(versions, ln->value, ",",
                            SPLIT_SKIP_SPACE|SPLIT_IGNORE_BLANK, 0);
   }
-  sort_version_list(versions);
+  sort_version_list(versions, 1);
   result = smartlist_join_strings(versions,",",0,NULL);
   SMARTLIST_FOREACH(versions,char *,s,tor_free(s));
   smartlist_free(versions);
   return result;
 }
 
-/** Generate a new directory and write it into a newly allocated string.
+/** Return 1 if <b>ri</b>'s descriptor is worth including in the v1
+ * directory, else return 0.
+ */
+static int
+live_enough_for_v1_dir(routerinfo_t *ri, time_t now)
+{
+  time_t cutoff = now - ROUTER_MAX_AGE_TO_PUBLISH;
+  if (ri->cache_info.published_on < cutoff)
+    return 0;
+  if (!ri->is_running || !ri->is_valid)
+    return 0;
+  return 1;
+}
+
+/** Generate a new v1 directory and write it into a newly allocated string.
  * Point *<b>dir_out</b> to the allocated string.  Sign the
  * directory with <b>private_key</b>.  Return 0 on success, -1 on
  * failure.
@@ -764,7 +777,6 @@ dirserv_dump_directory_to_string(char **dir_out,
   size_t identity_pkey_len;
   routerlist_t *rl = router_get_routerlist();
   time_t now = time(NULL);
-  time_t cutoff = now - ROUTER_MAX_AGE_TO_PUBLISH;
 
   tor_assert(dir_out);
   *dir_out = NULL;
@@ -786,7 +798,7 @@ dirserv_dump_directory_to_string(char **dir_out,
   buf_len = 2048+strlen(recommended_versions)+
     strlen(router_status);
   SMARTLIST_FOREACH(rl->routers, routerinfo_t *, ri,
-                    if (ri->cache_info.published_on >= cutoff)
+                    if (live_enough_for_v1_dir(ri, now))
                       buf_len += ri->cache_info.signed_descriptor_len+1);
   buf = tor_malloc(buf_len);
   /* We'll be comparing against buf_len throughout the rest of the
@@ -812,7 +824,7 @@ dirserv_dump_directory_to_string(char **dir_out,
     {
       size_t len = ri->cache_info.signed_descriptor_len;
       const char *body;
-      if (ri->cache_info.published_on < cutoff)
+      if (!live_enough_for_v1_dir(ri, now))
         continue;
       if (cp+len+1 >= buf+buf_len)
         goto truncated;
@@ -957,7 +969,7 @@ dirserv_set_cached_networkstatus_v2(const char *networkstatus,
     digestmap_remove(cached_v2_networkstatus, identity);
   }
 
-  router_get_trusted_dir_servers(&trusted_dirs);
+  trusted_dirs = router_get_trusted_dir_servers();
   if (digestmap_size(cached_v2_networkstatus) >
       smartlist_len(trusted_dirs) + MAX_UNTRUSTED_NETWORKSTATUSES) {
     /* We need to remove the oldest untrusted networkstatus. */
@@ -1066,7 +1078,7 @@ dirserv_get_directory(const char **directory, int compress)
 }
 
 /**
- * Generate a fresh directory (authdirservers only.)
+ * Generate a fresh v1 directory (authdirservers only.)
  */
 static int
 dirserv_regenerate_directory(void)
@@ -1178,18 +1190,27 @@ static uint32_t stable_uptime = 0; /* start at a safe value */
 static uint32_t fast_bandwidth = 0;
 static uint32_t guard_bandwidth = 0;
 
+static INLINE int
+real_uptime(routerinfo_t *router, time_t now)
+{
+  return router->uptime + (now - router->cache_info.published_on);
+}
+
 /** Return 1 if <b>router</b> is not suitable for these parameters, else 0.
  * If <b>need_uptime</b> is non-zero, we require a minimum uptime.
  * If <b>need_capacity</b> is non-zero, we require a minimum advertised
  * bandwidth.
  */
 static int
-dirserv_thinks_router_is_unreliable(routerinfo_t *router,
+dirserv_thinks_router_is_unreliable(time_t now,
+                                    routerinfo_t *router,
                                     int need_uptime, int need_capacity)
 {
-  if (need_uptime && router->uptime < stable_uptime)
+  if (need_uptime &&
+      (unsigned)real_uptime(router, now) < stable_uptime)
     return 1;
-  if (need_capacity && router->bandwidthcapacity < fast_bandwidth)
+  if (need_capacity &&
+      router_get_advertised_bandwidth(router) < fast_bandwidth)
     return 1;
   return 0;
 }
@@ -1204,12 +1225,13 @@ _compare_uint32(const void **a, const void **b)
 }
 
 /** Look through the routerlist, and assign the median uptime
- * of running valid servers to stable_uptime, and the median bandwidth
- * capacity to fast_bandwidth. */
+ * of running valid servers to stable_uptime, and the relative bandwidth
+ * capacities to fast_bandwidth and guard_bandwidth. */
 static void
 dirserv_compute_performance_thresholds(routerlist_t *rl)
 {
   smartlist_t *uptimes, *bandwidths;
+  time_t now = time(NULL);
 
   uptimes = smartlist_create();
   bandwidths = smartlist_create();
@@ -1218,9 +1240,9 @@ dirserv_compute_performance_thresholds(routerlist_t *rl)
     if (ri->is_running && ri->is_valid) {
       uint32_t *up = tor_malloc(sizeof(uint32_t));
       uint32_t *bw = tor_malloc(sizeof(uint32_t));
-      *up = (uint32_t) ri->uptime;
+      *up = (uint32_t) real_uptime(ri, now);
       smartlist_add(uptimes, up);
-      *bw = (uint32_t) ri->bandwidthcapacity;
+      *bw = router_get_advertised_bandwidth(ri);
       smartlist_add(bandwidths, bw);
     }
   });
@@ -1324,8 +1346,8 @@ generate_v2_networkstatus(void)
                "contact %s\n"
                "published %s\n"
                "dir-options%s%s\n"
-               "client-versions %s\n"
-               "server-versions %s\n"
+               "%s%s" /* client versions %s */
+               "%s%s%s" /* \nserver versions %s \n */
                "dir-signing-key\n%s\n",
                hostname, ipaddr, (int)options->DirPort,
                fingerprint,
@@ -1333,8 +1355,11 @@ generate_v2_networkstatus(void)
                published,
                naming ? " Names" : "",
                versioning ? " Versions" : "",
+               versioning ? "client-versions " : "",
                client_versions,
+               versioning ? "\nserver-versions " : "",
                server_versions,
+               versioning ? "\n" : "",
                identity_pkey);
   outp = status + strlen(status);
   endp = status + len;
@@ -1350,19 +1375,23 @@ generate_v2_networkstatus(void)
   SMARTLIST_FOREACH(rl->routers, routerinfo_t *, ri, {
     if (ri->cache_info.published_on >= cutoff) {
       int f_exit = exit_policy_is_general_exit(ri->exit_policy);
+      /* These versions dump connections with idle live circuits
+         sometimes. D'oh!*/
+      int unstable_version =
+        tor_version_as_new_as(ri->platform,"0.1.1.10-alpha") &&
+        !tor_version_as_new_as(ri->platform,"0.1.1.16-rc-cvs");
       int f_stable = ri->is_stable =
-                     !dirserv_thinks_router_is_unreliable(ri, 1, 0);
+        !dirserv_thinks_router_is_unreliable(now, ri, 1, 0) &&
+        !unstable_version;
       int f_fast = ri->is_fast =
-                   !dirserv_thinks_router_is_unreliable(ri, 0, 1);
+        !dirserv_thinks_router_is_unreliable(now, ri, 0, 1);
       int f_running = ri->is_running; /* computed above */
       int f_authority = router_digest_is_trusted_dir(
                                       ri->cache_info.identity_digest);
       int f_named = naming && ri->is_named;
       int f_valid = ri->is_valid;
       int f_guard = f_fast && f_stable &&
-                    ri->bandwidthcapacity > guard_bandwidth &&
-                    (!tor_version_as_new_as(ri->platform,"0.1.1.10-alpha") ||
-                     tor_version_as_new_as(ri->platform,"0.1.1.16-rc-cvs"));
+        router_get_advertised_bandwidth(ri) > guard_bandwidth;
       /* 0.1.1.9-alpha is the first version to support fetch by descriptor
        * hash. */
       int f_v2_dir = ri->dir_port &&
@@ -1439,12 +1468,9 @@ generate_v2_networkstatus(void)
 /** Look for a network status object as specified by <b>key</b>, which should
  * be either "authority" (to find a network status generated by us), a hex
  * identity digest (to find a network status generated by given directory), or
- * "all" (to return all the v2 network status objects we have, concatenated).
- * If <b>compress</b>, find the version compressed with zlib.  Return 0 if
- * nothing was found; otherwise set *<b>directory</b> to the matching network
- * status and return its length.
+ * "all" (to return all the v2 network status objects we have).
  */
-int
+void
 dirserv_get_networkstatus_v2(smartlist_t *result,
                              const char *key)
 {
@@ -1453,7 +1479,7 @@ dirserv_get_networkstatus_v2(smartlist_t *result,
   if (!cached_v2_networkstatus)
     cached_v2_networkstatus = digestmap_new();
 
-  if (!(strcmp(key,"authority"))) {
+  if (!strcmp(key,"authority")) {
     if (get_options()->AuthoritativeDir) {
       cached_dir_t *d =
         dirserv_pick_cached_dir_obj(NULL,
@@ -1503,7 +1529,6 @@ dirserv_get_networkstatus_v2(smartlist_t *result,
         });
     smartlist_free(digests);
   }
-  return 0;
 }
 
 /** Add a signed_descriptor_t to <b>descs_out</b> for each router matching
@@ -1613,20 +1638,21 @@ dirserv_orconn_tls_done(const char *address,
     int drop = 0;
     if (strcasecmp(address, ri->address) || or_port != ri->or_port)
       continue;
+    /* XXX For 0.1.2.x, we should do something smarter here than !is_valid. */
     if (!ri->is_valid) {
       /* We have a router at the same address! */
       if (strcasecmp(ri->nickname, nickname_rcvd)) {
         log_notice(LD_DIRSERV,
-                   "Dropping descriptor: nickname '%s' does not match "
-                   "nickname '%s' in cert from %s:%d",
+                   "Dropping old invalid descriptor: nickname '%s' does "
+                   "not match nickname '%s' in new cert from %s:%d",
                    ri->nickname, nickname_rcvd, address, or_port);
         drop = 1;
       } else if (memcmp(ri->cache_info.identity_digest, digest_rcvd,
                         DIGEST_LEN)) {
         log_notice(LD_DIRSERV,
-                   "Dropping descriptor: identity key does not match "
-                   "key in cert from %s:%d",
-                   address, or_port);
+                   "Dropping old invalid descriptor for nickname '%s': "
+                   "identity key does not match key in new cert from %s:%d",
+                   ri->nickname, address, or_port);
         drop = 1;
       }
     }
