@@ -1,9 +1,9 @@
 /* Copyright (c) 2001-2004, Roger Dingledine.
  * Copyright (c) 2004-2006, Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: policies.c,v 1.1 2006/03/27 02:25:34 arma Exp $ */
+/* $Id: policies.c,v 1.2 2006/04/08 05:43:52 nickm Exp $ */
 const char policies_c_id[] = \
-  "$Id: policies.c,v 1.1 2006/03/27 02:25:34 arma Exp $";
+  "$Id: policies.c,v 1.2 2006/04/08 05:43:52 nickm Exp $";
 
 /**
  * \file policies.c
@@ -262,7 +262,8 @@ load_policy_from_option(config_line_t *config, addr_policy_t **policy,
   }
 }
 
-void policies_parse_from_options(or_options_t *options)
+void
+policies_parse_from_options(or_options_t *options)
 {
   load_policy_from_option(options->SocksPolicy, &socks_policy, -1);
   load_policy_from_option(options->DirPolicy, &dir_policy, -1);
@@ -273,7 +274,6 @@ void policies_parse_from_options(or_options_t *options)
   parse_reachable_addresses();
 }
 
-
 /** Compare two provided address policy items, and return -1, 0, or 1
  * if the first is less than, equal to, or greater than the second. */
 static int
