@@ -1,8 +1,8 @@
 /* Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: rendservice.c,v 1.157 2006/03/06 00:25:39 nickm Exp $ */
+/* $Id: rendservice.c,v 1.159 2006/03/19 01:21:59 arma Exp $ */
 const char rendservice_c_id[] =
-  "$Id: rendservice.c,v 1.157 2006/03/06 00:25:39 nickm Exp $";
+  "$Id: rendservice.c,v 1.159 2006/03/19 01:21:59 arma Exp $";
 
 /**
  * \file rendservice.c
@@ -27,7 +27,7 @@ typedef struct rend_service_port_config_t {
 #define NUM_INTRO_POINTS 3
 
 /** If we can't build our intro circuits, don't retry for this long. */
-#define INTRO_CIRC_RETRY_PERIOD 60*5
+#define INTRO_CIRC_RETRY_PERIOD (60*5)
 /** Don't try to build more than this many circuits before giving up
  * for a while.*/
 #define MAX_INTRO_CIRCS_PER_PERIOD 10
@@ -927,10 +927,6 @@ upload_service_descriptor(rend_service_t *service, int version)
   service->desc_is_dirty = 0;
 }
 
-/* XXXX Make this longer once directories remember service descriptors across
- * restarts.*/
-#define MAX_SERVICE_PUBLICATION_INTERVAL (15*60)
-
 /** For every service, check how many intro points it currently has, and:
  *  - Pick new intro points as necessary.
  *  - Launch circuits to any new intro points.
@@ -1003,7 +999,7 @@ rend_services_introduce(void)
       char *hex_digest;
       router = router_choose_random_node(service->intro_prefer_nodes,
                service->intro_exclude_nodes, exclude_routers, 1, 0, 0,
-               get_options()->_AllowUnverified & ALLOW_UNVERIFIED_INTRODUCTION,
+               get_options()->_AllowInvalid & ALLOW_INVALID_INTRODUCTION,
                0);
       if (!router) {
         log_warn(LD_REND,
