@@ -1,9 +1,9 @@
 /* Copyright 2001-2004 Roger Dingledine.
  * Copyright 2004-2006 Roger Dingledine, Nick Mathewson. */
 /* See LICENSE for licensing information */
-/* $Id: test.c,v 1.222 2006/03/05 09:50:26 nickm Exp $ */
+/* $Id: test.c,v 1.224 2006/03/27 02:25:34 arma Exp $ */
 const char test_c_id[] =
-  "$Id: test.c,v 1.222 2006/03/05 09:50:26 nickm Exp $";
+  "$Id: test.c,v 1.224 2006/03/27 02:25:34 arma Exp $";
 
 /**
  * \file test.c
@@ -1453,11 +1453,11 @@ test_exit_policies(void)
 
 //  test_assert(exit_policy_implicitly_allows_local_networks(policy, 0));
   test_assert(ADDR_POLICY_ACCEPTED ==
-          router_compare_addr_to_addr_policy(0x01020304u, 2, policy));
+          compare_addr_to_addr_policy(0x01020304u, 2, policy));
   test_assert(ADDR_POLICY_PROBABLY_ACCEPTED ==
-          router_compare_addr_to_addr_policy(0, 2, policy));
+          compare_addr_to_addr_policy(0, 2, policy));
   test_assert(ADDR_POLICY_REJECTED ==
-          router_compare_addr_to_addr_policy(0xc0a80102, 2, policy));
+          compare_addr_to_addr_policy(0xc0a80102, 2, policy));
 
   addr_policy_free(policy);
 
@@ -1614,12 +1614,17 @@ int
 main(int c, char**v)
 {
   or_options_t *options = options_new();
+  char *errmsg = NULL;
   options->command = CMD_RUN_UNITTESTS;
   network_init();
   setup_directory();
   options_init(options);
   options->DataDirectory = tor_strdup(temp_dir);
-  set_options(options);
+  if (set_options(options, &errmsg) < 0) {
+    printf("Failed to set initial options: %s\n", errmsg);
+    tor_free(errmsg);
+    return 1;
+  }
 
   crypto_seed_rng();
 
